/********************************************************************/
/*    TORQUE (Types Of Relationships QUality Evaluation) toolkit    */
/*                                                                  */
/* Original file name: consoletools.cc                              */
/*                                                                  */
/* This software by R.M.                                            */
/********************************************************************/

#include "consoletools.h"

/* This function displays a warning message for a file that is
   about to be overwritten, and asks user confirmation about it */
bool askOverwrite (char *fileName) {
   char c;
   bool ok;
   fprintf (stderr, "Warning: file `%s'\nalready exists and is about to be overwritten.\n",
            fileName);
   fprintf (stderr, "Do you want to proceed (y/n)? ");
   fflush (stderr);
   c = getchar();
   ok = c == 'Y' || c == 'y';
   // Flush input buffer
   while (c != '\n') {
      c = getchar();
   }
   return ok;
}

// Moves cursor to a given column, same row
void goToCol(int n) {
   printf ("\033[%iG", n);
}

// Prints a percentage bar
void printPercentage(float curValue, float totValue) {
   static float oldPerc = -1;
   short int i;
   float perc;
   perc = curValue / totValue * (float) 100;
   /* Only display percentage bar if something has changed
      since last call */
   if (perc - oldPerc >= 0.5 || 100 - perc < 1E-3 ||
       perc - oldPerc < 0) {
      goToCol (1);
      printf ("[");
      for (i = 1; i <= perc / 2.5; i++) {
         printf ("*");
      }
      for (; i <= 40; i++) {
         printf (" ");
      }
      printf ("]  (%3.1f %%)", perc);
      fflush(stdout);
      oldPerc = perc;
   }
}

/* This function returns true if the given stream appears to
   be connected to a terminal; false otherwise */
bool isTerm(FILE *stream) {
   struct stat s;
   fstat(fileno(stream), &s);
   return (S_ISCHR(s.st_mode));
}
